@@ -29,10 +29,10 @@ get_details_trading_hours_stock_market_holidays <- function(api_token, code, fro
   query_string <- list()
 
   if (!is.null(from_date)) {
-    query_string$from_date <- as.character(from_date)
+    query_string$from <- as.character(from_date)
   }
   if (!is.null(to_date)) {
-    query_string$to_date <- as.character(to_date)
+    query_string$to <- as.character(to_date)
   }
 
   return(rest_get_method(api_key = api_token, endpoint = endpoint, uri = uri, querystring = query_string))
