@@ -27,10 +27,10 @@ get_upcoming_earnings_data <- function(api_token, from_date = NULL, to_date = NU
   query_string <- list()
 
   if (!is.null(from_date)) {
-    query_string$from_date <- as.character(from_date)
+    query_string$from <- as.character(from_date)
   }
   if (!is.null(to_date)) {
-    query_string$to_date <-  as.character(to_date)
+    query_string$to <-  as.character(to_date)
   }
   if (!is.null(symbols)) {
     query_string$symbols <- as.character(symbols)
